ハロー・ゼロ
============

使い方
------

:)

`pip install i0`

Then run:

`i0`

Or:

`i0 --path ~/.metadrive --host 0.0.0.0 --port 8000`

ノート
------

:( we could say, general interfaces are missing in federation, e.g.:

1. Can't comment in RSS.
2. Can't reply emails serialized in RSS.
3. Can't reply telegram in RSS.
4. Can't confirm money transfers serialized in RSS.
5. Can't sign contracts serlized in RSS (work contracts, service contracts, supply contracts, cooperation contracts, etc.).

In general, objects don't carry their interfaces provided by drivers.
